@@ -5,6 +5,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+.import QtQml 2.15 as QtQml
 .import org.kde.taskmanager 0.1 as TaskManager
 .import org.kde.plasma.core 2.0 as PlasmaCore // Needed by TaskManager
 
@@ -47,7 +48,8 @@ function activateNextPrevTask(anchor, next) {
 
                 for (var j = 0; j < tasksModel.rowCount(modelIndex); ++j) {
                     const childModelIndex = tasksModel.makeModelIndex(i, j);
-                    if (!task.m.IsHidden) {
+                    const childHidden = tasksModel.data(childModelIndex, TaskManager.AbstractTasksModel.IsHidden);
+                    if (!plasmoid.configuration.wheelSkipMinimized || !childHidden) {
                         taskIndexList.push(childModelIndex);
                     }
                 }
@@ -56,7 +58,7 @@ function activateNextPrevTask(anchor, next) {
                     break;
                 }
             } else {
-                if (!task.m.IsHidden) {
+                if (!plasmoid.configuration.wheelSkipMinimized || !task.m.IsHidden) {
                     taskIndexList.push(modelIndex);
                 }
             }
@@ -157,16 +159,16 @@ function activateTask(index, model, modifiers, task) {
             }
         }
 
-        // Option 3: show Present Windows for all child tasks
+        // Option 3: show Window View for all child tasks
         // ==================================================
-        // Make sure the Present Windows effect is  are actually enabled though;
+        // Make sure the Window View effect is  are actually enabled though;
         // if not, fall through to the next option.
-        else if (backend.canPresentWindows
+        else if (backend.windowViewAvailable
             && (plasmoid.configuration.groupedTaskVisualization === 2
             || plasmoid.configuration.groupedTaskVisualization === 1)
         ) {
             task.hideToolTipTemporarily();
-            tasks.presentWindows(model.WinIdList);
+            tasks.activateWindowView(model.WinIdList);
         }
 
         // Option 4: show group dialog/textual list
@@ -174,12 +176,11 @@ function activateTask(index, model, modifiers, task) {
         // This is also the final fallback option if Tooltips or Present windows
         // are chosen but not actually available
         else {
-            if (groupDialog.visible) {
+            if (!!groupDialog) {
                 task.hideToolTipTemporarily();
                 groupDialog.visible = false;
             } else {
-                groupDialog.visualParent = task;
-                groupDialog.visible = true;
+                createGroupDialog(task);
             }
         }
     } else {
@@ -252,3 +253,22 @@ function taskPrefixHovered(prefix) {
 
     return effectivePrefix;
 }
+
+function createGroupDialog(visualParent) {
+    if (!visualParent) {
+        return;
+    }
+
+    if (!!tasks.groupDialog) {
+        tasks.groupDialog.visualParent = visualParent;
+        return;
+    }
+
+    if (groupDialogComponent.status === QtQml.Component.Ready) {
+        tasks.groupDialog = groupDialogComponent.createObject(tasks,
+            {
+                visualParent: visualParent,
+            }
+        );
+    }
+}
