@@ -21,6 +21,7 @@ static const QLatin1String desktop(QLatin1String("Desktop"));
 
 void PositionerTest::initTestCase()
 {
+    m_currentActivity = QStringLiteral("00000000-0000-0000-0000-000000000000");
     m_folderDir = new QTemporaryDir();
 
     QDir dir(m_folderDir->path());
@@ -232,7 +233,8 @@ void PositionerTest::tst_proxyMapping()
         auto ensureUnique = [](const QHash<int, int> mapping) {
             auto values = mapping.values();
             std::sort(values.begin(), values.end());
-            auto uniqueValues = values.toSet().values();
+            auto uniqueValues = values;
+            uniqueValues.erase(std::unique(uniqueValues.begin(), uniqueValues.end()), uniqueValues.end());
             std::sort(uniqueValues.begin(), uniqueValues.end());
             QVERIFY(uniqueValues == values);
         };
@@ -249,7 +251,7 @@ void PositionerTest::tst_proxyMapping()
     const auto movedItem = m_folderModel->index(1, 0).data(FolderModel::UrlRole).toUrl();
 
     // move the item 1 from source (now in position 2) to the second screen
-    screenMapper->addMapping(movedItem, 1);
+    screenMapper->addMapping(movedItem, 1, m_currentActivity);
 
     expectedProxy2SourceScreen1[0] = 0;
     expectedSource2ProxyScreen1[0] = 0;
@@ -268,7 +270,7 @@ void PositionerTest::tst_proxyMapping()
     verifyMapping(secondPositioner.sourceToProxyMapping(), expectedSource2ProxyScreen1);
 
     // move back the same item to the first screen
-    screenMapper->addMapping(movedItem, 0);
+    screenMapper->addMapping(movedItem, 0, m_currentActivity);
 
     // nothing on the second screen
     expectedSource2ProxyScreen1.clear();
