@@ -59,8 +59,8 @@ public:
 Q_SIGNALS:
     void error(const QString &string);
 
-protected:
-    void handleError(KIO::Job *job) override;
+private:
+    void handleJobError(KIO::Job *job);
 };
 
 class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, public QQmlParserStatus
@@ -352,6 +352,11 @@ private:
     QObject *m_appletInterface = nullptr;
     bool m_complete;
     QPoint m_menuPosition;
+
+    /**
+     * This property is used to save the current activity when FolderModel is initialized.
+     */
+    QString m_currentActivity;
 };
 
 class DragTracker : public QObject
