@@ -8,6 +8,7 @@
 #define KCM_ADD_LAYOUT_DIALOG_H_
 
 #include <QDialog>
+#include <QListWidgetItem>
 
 #include "keyboard_config.h"
 
@@ -17,6 +18,8 @@ struct Rules;
 class Flags;
 class Ui_AddLayoutDialog;
 
+enum LayoutDataRoles { LayoutNameRole = Qt::UserRole, VariantNameRole };
+
 class AddLayoutDialog : public QDialog
 {
     Q_OBJECT
@@ -31,8 +34,8 @@ public:
     void accept() override;
 
 public Q_SLOTS:
-    void languageChanged(int langIdx);
-    void layoutChanged(int layoutIdx);
+    void layoutChanged(QListWidgetItem *, QListWidgetItem *);
+    void layoutSearched(const QString &);
     void preview();
 
 private:
@@ -41,7 +44,6 @@ private:
     const QString &model;
     const QStringList &options;
     Ui_AddLayoutDialog *layoutDialogUi;
-    QString selectedLanguage;
     QString selectedLayout;
     LayoutUnit selectedLayoutUnit;
 };
