@@ -19,7 +19,6 @@
 #include <QStandardItemModel>
 #include <QStandardPaths>
 
-#include <KPackage/Package>
 #include <KPackage/PackageLoader>
 #include <KPackage/PackageStructure>
 
@@ -33,8 +32,8 @@ KCMSplashScreen::KCMSplashScreen(QObject *parent, const QVariantList &args)
     , m_data(new SplashScreenData(this))
     , m_model(new QStandardItemModel(this))
 {
-    qmlRegisterType<SplashScreenSettings>();
-    qmlRegisterType<QStandardItemModel>();
+    qmlRegisterAnonymousType<SplashScreenSettings>("org.kde.plasma.splash.kcm", 0);
+    qmlRegisterAnonymousType<QStandardItemModel>("org.kde.plasma.splash.kcm", 0);
 
     KAboutData *about = new KAboutData(QStringLiteral("kcm_splashscreen"), i18n("Splash Screen"), QStringLiteral("0.1"), QString(), KAboutLicense::LGPL);
     about->addAuthor(i18n("Marco Martin"), QString(), QStringLiteral("mart@kde.org"));
@@ -247,3 +246,4 @@ void KCMSplashScreen::defaults()
 }
 
 #include "kcm.moc"
+#include "moc_kcm.cpp"
