@@ -76,7 +76,7 @@ void MostUsedModel::setResultModel(ResultModel *model)
     }
 
     auto updateModel = [this]() {
-        if (m_resultModel->rowCount() >= 5) {
+        if (m_resultModel->rowCount() >= 6) {
             setSourceModel(m_resultModel);
         } else {
             setSourceModel(m_defaultModel);
@@ -160,12 +160,12 @@ KCMLandingPage::KCMLandingPage(QObject *parent, const QVariantList &args)
     : KQuickAddons::ManagedConfigModule(parent, args)
     , m_data(new LandingPageData(this))
 {
-    qmlRegisterType<LandingPageGlobalsSettings>();
+    qmlRegisterAnonymousType<LandingPageGlobalsSettings>("org.kde.plasma.landingpage.kcm", 0);
 #if HAVE_KUSERFEEDBACK
-    qmlRegisterType<FeedbackSettings>();
+    qmlRegisterAnonymousType<FeedbackSettings>("org.kde.plasma.landingpage.kcm", 0);
 #endif
-    qmlRegisterType<MostUsedModel>();
-    qmlRegisterType<LookAndFeelGroup>();
+    qmlRegisterAnonymousType<MostUsedModel>("org.kde.plasma.landingpage.kcm", 0);
+    qmlRegisterAnonymousType<LookAndFeelGroup>("org.kde.plasma.landingpage.kcm", 0);
 
     KAboutData *about = new KAboutData(QStringLiteral("kcm_landingpage"),
                                        i18n("Quick Settings"),
@@ -179,7 +179,7 @@ KCMLandingPage::KCMLandingPage(QObject *parent, const QVariantList &args)
     setButtons(Apply | Help);
 
     m_mostUsedModel = new MostUsedModel(this);
-    m_mostUsedModel->setResultModel(new ResultModel(AllResources | Agent(QStringLiteral("org.kde.systemsettings")) | HighScoredFirst | Limit(5), this));
+    m_mostUsedModel->setResultModel(new ResultModel(AllResources | Agent(QStringLiteral("org.kde.systemsettings")) | HighScoredFirst | Limit(6), this));
 
     m_defaultLightLookAndFeel = new LookAndFeelGroup(this);
     m_defaultDarkLookAndFeel = new LookAndFeelGroup(this);
@@ -242,7 +242,7 @@ void KCMLandingPage::programFinished(int exitCode)
             continue;
         }
 
-        const QString description = line.mid(sepIdx + 2);
+        const QString description = line.mid(sepIdx + 1);
         m_uses[modeValue][description] << s_programs[program];
     }
     p->deleteLater();
@@ -374,3 +374,4 @@ Q_INVOKABLE void KCMLandingPage::openKCM(const QString &kcm)
 }
 
 #include "landingpage.moc"
+#include "moc_landingpage.cpp"
